==> miodi-0.2.5.tar.gz: test/miodi_test.dart <==
import 'package:miodi/miodi.dart';
import 'package:test/test.dart';

void main() {
  Miodi.init([appComponent]);

  test('Test factory providers', () {
    User user1 = inject();
    expect(userCounter, equals(1));
    User user2 = inject();
    expect(userCounter, equals(2));
    User user3 = inject();
    expect(userCounter, equals(3));
  });

  test('Test singleton providers', () {
    Database database1 = inject();
    expect(databaseCounter, 1);
    Database database2 = inject();
    expect(databaseCounter, 1);
    Database database3 = inject();
    expect(databaseCounter, 1);
  });

  test('Test scope providers', () {
    ScopeObject scopeObject1 = scopeInject(AppComponent.testScope);
    expect(scopeObjCount, 1);
    ScopeObject scopeObject2 = scopeInject(AppComponent.testScope);
    expect(scopeObjCount, 1);
    clearScope(AppComponent.testScope);
    ScopeObject scopeObject3 = scopeInject(AppComponent.testScope);
    expect(scopeObjCount, 2);
    ScopeObject scopeObject4 = scopeInject(AppComponent.testScope);
    expect(scopeObjCount, 2);
    clearScope(AppComponent.testScope);
  });

  return;
}

final appComponent = AppComponent();

class AppComponent extends MiodiComponent {
  static String testScope = 'test';

  @override
  List<MiodiModule> get modules => [
        module([
          singleton(Database, () => DatabaseImpl()),
          factory(User, () => User()),
          scope(testScope, ScopeObject, () => ScopeObject())
        ]),
      ];
}

var scopeObjCount = 0;
class ScopeObject {
  ScopeObject() {
    scopeObjCount++;
    print('scopeObjCount: $scopeObjCount');
  }
}

var databaseCounter = 0;
abstract class Database {
  void printDatabaseCounter();
}

class DatabaseImpl implements Database {
  DatabaseImpl() {
    databaseCounter++;
    printDatabaseCounter();
  }

  @override
  void printDatabaseCounter() {
    print("Database: " + databaseCounter.toString());
  }
}

var userCounter = 0;
class User {
  User() {
    userCounter++;
    print('User: $userCounter');
  }
}

==> miodi-0.3.0.tar.gz: test/miodi_test.dart <==
import 'package:miodi/miodi.dart';
import 'package:test/test.dart';

void main() {
  Miodi.init([appComponent]);

  test('Test factory providers', () {
    User user1 = Miodi.inject();
    expect(userCounter, equals(1));
    User user2 = Miodi.inject();
    expect(userCounter, equals(2));
    User user3 = Miodi.inject();
    expect(userCounter, equals(3));
  });

  test('Test singleton providers', () {
    Database database1 = Miodi.inject();
    expect(databaseCounter, 1);
    Database database2 = Miodi.inject();
    expect(databaseCounter, 1);
    Database database3 = Miodi.inject();
    expect(databaseCounter, 1);
  });

  test('Test scope providers', () {
    ScopeObject scopeObject1 = Miodi.inject();
    expect(scopeObjCount, 1);
    ScopeObject scopeObject2 = Miodi.inject();
    expect(scopeObjCount, 1);
  });

  return;
}

final appComponent = AppComponent();

class AppComponent extends MiodiComponent {

  @override
  List<MiodiModule> get modules => [
        module([
          singleton(Database, () => DatabaseImpl()),
          factory(User, () => User()),
          scope(ScopeObject, () => ScopeObject())
        ]),
      ];
}

var scopeObjCount = 0;
class ScopeObject {
  ScopeObject() {
    scopeObjCount++;
    print('scopeObjCount: $scopeObjCount');
  }
}

var databaseCounter = 0;
abstract class Database {
  void printDatabaseCounter();
}

class DatabaseImpl implements Database {
  DatabaseImpl() {
    databaseCounter++;
    printDatabaseCounter();
  }

  @override
  void printDatabaseCounter() {
    print("Database: " + databaseCounter.toString());
  }
}

var userCounter = 0;
class User {
  User() {
    userCounter++;
    print('User: $userCounter');
  }
}
